.. Tradier Python documentation master file, created by
   sphinx-quickstart on Fri Oct  8 15:21:02 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Tradier Python's documentation!
==========================================

This is a python client for interacting with the Tradier API. Most of the documentation was taken directly from the official API docs. Please reference them for more details.

https://documentation.tradier.com/brokerage-api


.. toctree::
   :maxdepth: 2
   :caption: Contents:

TradierPython main
===================
.. autoclass:: tradier_python.TradierAPI
   :members:

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
